@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: bufferstore.h,v 1.11 2002/07/14 19:07:04 felfert Exp $
+ * $Id: bufferstore.h,v 1.13 2005/04/16 15:21:47 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -24,8 +24,9 @@
 #ifndef _BUFFERSTORE_H_
 #define _BUFFERSTORE_H_
 
+#include <iostream>
+
 #include <sys/types.h>
-#include <stream.h>
 
 /**
  * A generic container for an array of bytes.
@@ -129,7 +130,7 @@ public:
     *
     * @returns The stream.
     */
-    friend class std::ostream &operator<<(std::ostream &, const bufferStore &);
+    friend std::ostream &operator<<(std::ostream &, const bufferStore &);
 
     /**
     * Tests if the bufferStore is empty.
