@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: iowatch.cc,v 1.6 2002/08/11 01:41:44 felfert Exp $
+ * $Id: iowatch.cc,v 1.7 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -21,15 +21,18 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "iowatch.h"
+
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <stream.h>
 #include <memory.h>
 
-#include "iowatch.h"
-
 IOWatch::IOWatch() {
     num = 0;
     io = new int [FD_SETSIZE];
