@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: log.cc,v 1.6 2003/02/03 00:56:52 felfert Exp $
+ * $Id: log.cc,v 1.7 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -22,13 +22,14 @@
  *
  */
 #include "log.h"
+
 #include <unistd.h>
 
-logbuf::logbuf(int level, int fd) {
+logbuf::logbuf(int loglevel, int fd) {
     ptr = buf;
     len = 0;
     _on = true;
-    _level = level;
+    _level = loglevel;
     _fd = fd;
 }
 
