@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rfsvfactory.cc,v 1.8 2006/09/29 00:16:28 rrt Exp $
+ * $Id: rfsvfactory.cc,v 1.9 2008/04/06 21:35:38 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -41,7 +41,7 @@ ENUM_DEFINITION_BEGIN(rfsvfactory::errs, rfsvfactory::FACERR_NONE)
     stringRep.add(rfsvfactory::FACERR_NONE,           N_("no error"));
     stringRep.add(rfsvfactory::FACERR_COULD_NOT_SEND, N_("could not send version request"));
     stringRep.add(rfsvfactory::FACERR_AGAIN,          N_("try again"));
-    stringRep.add(rfsvfactory::FACERR_NOPSION,        N_("no psion connected"));
+    stringRep.add(rfsvfactory::FACERR_NOPSION,        N_("no EPOC device connected"));
     stringRep.add(rfsvfactory::FACERR_PROTVERSION,    N_("wrong protocol version"));
     stringRep.add(rfsvfactory::FACERR_NORESPONSE,     N_("no response from ncpd"));
 ENUM_DEFINITION_END(rfsvfactory::errs)
