@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rpcs16.cc,v 1.9 2002/07/14 19:07:04 felfert Exp $
+ * $Id: rpcs16.cc,v 1.10 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,19 +25,15 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <fstream.h>
-#include <iomanip.h>
-#include <time.h>
-#include <string.h>
-
 #include "rpcs16.h"
 #include "bufferstore.h"
 #include "bufferarray.h"
 #include "ppsocket.h"
 
+#include <stdio.h>
+#include <stdlib.h>
+#include <time.h>
+
 using namespace std;
 
 rpcs16::rpcs16(ppsocket * _skt)
