@@ -1,5 +1,5 @@
 /* -*-c++-*-
- * $Id: sislangrecord.h,v 1.5 2002/03/06 20:03:48 basic Exp $
+ * $Id: sislangrecord.h,v 1.6 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -23,7 +23,7 @@
 #ifndef _SISLANGRECORD_H
 #define _SISLANGRECORD_H
 
-#include "sistypes.h"
+#include <sistypes.h>
 
 /**
  * A simple language record, only containing the epoc specific 16 bit
