@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: wprt.cc,v 1.3 2002/03/03 23:49:27 felfert Exp $
+ * $Id: wprt.cc,v 1.4 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,19 +24,19 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
-#include <stdlib.h>
-#include <fstream.h>
-#include <iomanip.h>
-#include <time.h>
-#include <string.h>
-
 #include "wprt.h"
 #include "bufferstore.h"
 #include "ppsocket.h"
 #include "bufferarray.h"
 #include "Enum.h"
 
+#include <iostream>
+
+#include <stdlib.h>
+#include <time.h>
+
+using namespace std;
+
 wprt::wprt(ppsocket * _skt)
 {
     skt = _skt;
