@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: wprt.h,v 1.2 2002/03/03 23:49:27 felfert Exp $
+ * $Id: wprt.h,v 1.3 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -93,7 +93,7 @@ protected:
 	WPRT_INIT    = 0x00,
 	WPRT_GET     = 0xf0,
 	WPRT_CANCEL  = 0xf1,
-	WPRT_STOP    = 0xff,
+	WPRT_STOP    = 0xff
     };
 
     /**
