@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: main.h,v 1.1 2002/07/16 00:06:30 felfert Exp $
+ * $Id: main.h,v 1.2 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,7 +24,7 @@
 #ifndef _main_h_
 #define _main_h_
 
-#include <ostream.h>
+#include <iostream>
 
 extern std::ostream lout;
 extern std::ostream lerr;
