@@ -1,4 +1,4 @@
-/* $Id: mp_serial.c,v 1.7 2002/03/16 23:10:51 felfert Exp $
+/* $Id: mp_serial.c,v 1.8 2008/01/29 21:29:02 rrt Exp $
    //  PLP - An implementation of the PSION link protocol
    //
    //
@@ -38,9 +38,7 @@
 #ifdef sun
 #include <sys/ttold.h>		/* sun has TIOCEXCL there */
 #endif
-#if defined (__SVR4)
 #include <stdlib.h>
-#endif
 
 #ifndef hpux
 #define mflag int
@@ -49,12 +47,8 @@
 #include <sys/modem.h>
 #endif
 
+#include "mp_serial.h"
 
-/*
-   #if !defined(CRTSCTS) && defined(_IBMR2)
-   #define CRTSCTS 0x80000000
-   #endif
- */
 
 #ifdef __sgi
 #define CRTSCTS CNEW_RTSCTS
