@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: mp_serial.h,v 1.3 2002/02/14 06:22:08 felfert Exp $
+ * $Id: mp_serial.h,v 1.4 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,8 +24,14 @@
 #ifndef _mp_serial_h
 #define _mp_serial_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 int init_serial(const char *dev, int speed, int debug);
 void ser_exit(int fd);
+#ifdef __cplusplus
+}
+#endif
 
 #endif
 
