@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: socketchan.cc,v 1.18 2002/07/14 19:07:05 felfert Exp $
+ * $Id: socketchan.cc,v 1.19 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,17 +24,20 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <stream.h>
+
+#include <string>
+
+#include <ppsocket.h>
+#include <rfsv.h>
+
 #include <stdio.h>
-#include <string.h>
 #include <malloc.h>
 
 #include "socketchan.h"
 #include "ncp.h"
-#include <ppsocket.h>
-#include <rfsv.h>
+#include "main.h"
 
-extern std::ostream lerr;
+using namespace std;
 
 socketChan:: socketChan(ppsocket * _skt, ncp * _ncpController):
     channel(_ncpController)
