@@ -1,10 +1,11 @@
 /*-*-c++-*-
- * $Id: ftp.cc,v 1.40 2006/05/16 11:13:10 rrt Exp $
+ * $Id: ftp.cc,v 1.52 2008/04/06 21:55:06 rrt Exp $
  *
  * This file is part of plptools.
  *
  *  Copyright (C) 1999  Philip Proudman <philip.proudman@btinternet.com>
  *  Copyright (C) 1999-2002 Fritz Elfert <felfert@to.com>
+ *  Copyright (C) 2006-2008 Reuben Thomas <rrt@sc3d.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +22,16 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
-#undef EXPERIMENTAL
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <plpintl.h>
 #include <rfsv.h>
 #include <rpcs.h>
+#include <rclip.h>
+#include <plpintl.h>
+#include <ppsocket.h>
 #include <bufferarray.h>
 #include <bufferstore.h>
 #include <Enum.h>
@@ -49,6 +51,7 @@
 #include <sys/time.h>
 #include <sys/stat.h>
 #include <signal.h>
+#include <netdb.h>
 
 #include "ftp.h"
 
@@ -58,7 +61,6 @@ extern "C"  {
 #if HAVE_LIBHISTORY
 #include <readline/history.h>
 #endif
-#include "rlcrap.h"
 }
 #endif
 
@@ -68,6 +70,8 @@ static char psionDir[1024];
 static rfsv *comp_a;
 static int continueRunning;
 
+#define CLIPFILE "C:/System/Data/Clpboard.cbd"
+
 
 void ftp::
 resetUnixPwd()
@@ -115,6 +119,8 @@ void ftp::usage() {
     cout << endl << _("Known RPC commands:") << endl << endl;
     cout << "  ps" << endl;
     cout << "  kill <pid|'all'>" << endl;
+    cout << "  getclip <unixfile>" << endl;
+    cout << "  putclip <unixfile>" << endl;
     cout << "  run <psionfile> [args]" << endl;
     cout << "  killsave <unixfile>" << endl;
     cout << "  runrestore <unixfile>" << endl;
@@ -205,8 +211,441 @@ sigint_handler2(int i) {
     signal(SIGINT, sigint_handler2);
 }
 
+static int
+stopPrograms(rpcs & r, const char *file) {
+    Enum<rfsv::errs> res;
+    processList tmp;
+    FILE *fp = fopen(file, "w");
+
+    if (fp == NULL) {
+        cerr << _("Could not open command list file ") << file << endl;
+        return 1;
+    }
+    fputs("#plpftp processlist\n", fp);
+    if ((res = r.queryPrograms(tmp)) != rfsv::E_PSI_GEN_NONE) {
+        cerr << _("Could not get process list, Error: ") << res << endl;
+        return 1;
+    }
+    for (processList::iterator i = tmp.begin(); i != tmp.end(); i++) {
+        fputs(i->getArgs(), fp);
+        fputc('\n', fp);
+    }
+    fclose(fp);
+    time_t tstart = time(0) + 5;
+    while (!tmp.empty()) {
+        for (processList::iterator i = tmp.begin(); i != tmp.end(); i++) {
+            r.stopProgram(i->getProcId());
+        }
+        usleep(100000);
+        if (time(0) > tstart) {
+            cerr << _(
+                      "Could not stop all processes. Please stop running\n"
+                      "programs manually on the Psion, then hit return.") << flush;
+            cin.getline((char *)&tstart, 1);
+            tstart = time(0) + 5;
+        }
+        if ((res = r.queryPrograms(tmp)) != rfsv::E_PSI_GEN_NONE) {
+            cerr << _("Could not get process list, Error: ") << res << endl;
+            return 1;
+        }
+    }
+    return 0;
+}
+
+static char *
+get_upto(FILE *fp, const char *term, size_t *final_len)
+{
+    size_t len = 256;
+    int c;
+    char *l = (char *)malloc(len), *s = l;
+    
+    assert(l);
+    for (c = getc(fp); c != EOF && strchr(term, c) == NULL; c = getc(fp)) {
+        if (s == l + len) {
+            l = (char *)realloc(l, len * 2);
+            assert(l);
+            len *= 2;
+        }
+        *s++ = c;
+    }
+    if (s == l + len) {
+        l = (char *)realloc(l, len + 1);
+        assert(l);
+    }
+    *s++ = '\0';
+    
+    if (final_len)
+        *final_len = s - l;
+    l = (char *)realloc(l, s - l);
+    assert(l);
+    return l;
+}
+
+static char*
+getln(FILE *fp)
+{
+    return get_upto(fp, "\n", NULL);
+}
+
+static int
+startPrograms(rpcs & r, rfsv & a, const char *file) {
+    Enum<rfsv::errs> res;
+    FILE *fp = fopen(file, "r");
+    string cmd;
+
+    if (fp == NULL) {
+        cerr << _("Could not open command list file ") << file << endl;
+        return 1;
+    }
+    cmd = string(getln(fp));
+    if (strcmp(cmd.c_str(), "#plpftp processlist")) {
+        fclose(fp);
+        cerr << _("Error: ") << file <<
+            _(" is not a process list saved with killsave") << endl;
+        return 1;
+    }
+    for (cmd = string(getln(fp)); cmd.length() > 0; cmd = string(getln(fp))) {
+	int firstBlank = cmd.find(' ');
+	string prog = string(cmd, 0, firstBlank);
+	string arg = string(cmd, firstBlank + 1);
+
+	if (!prog.empty()) {
+	    // Workaround for broken programs like Backlite. These do not store
+	    // the full program path. In that case we try running the arg1 which
+	    // results in starting the program via recog. facility.
+	    if ((arg.size() > 2) && (arg[1] == ':') && (arg[0] >= 'A') &&
+		(arg[0] <= 'Z'))
+		res = r.execProgram(arg.c_str(), "");
+	    else
+		res = r.execProgram(prog.c_str(), arg.c_str());
+	    if (res != rfsv::E_PSI_GEN_NONE) {
+		// If we got an error here, that happened probably because
+		// we have no path at all (e.g. Macro5) and the program is
+		// not registered in the Psion's path properly. Now try
+		// the usual \System\Apps\<AppName>\<AppName>.app
+		// on all drives.
+		if (prog.find('\\') == prog.npos) {
+		    u_int32_t devbits;
+		    if ((res = a.devlist(devbits)) == rfsv::E_PSI_GEN_NONE) {
+			int i;
+			for (i = 0; i < 26; i++) {
+			    if (devbits & (1 << i)) {
+                                string tmp = string();
+                                tmp += ('A' + i);
+                                tmp += ":\\System\\Apps\\" + prog + "\\" + prog + ".app";
+				res = r.execProgram(tmp.c_str(), "");
+                                if (res == rfsv::E_PSI_GEN_NONE)
+                                    break;
+			    }
+			}
+		    }
+		}
+	    }
+	    if (res != rfsv::E_PSI_GEN_NONE) {
+		cerr << _("Could not start ") << cmd << endl;
+		cerr << _("Error: ") << res << endl;
+	    }
+	}
+    }
+    return 0;
+}
+
+bool
+ftp::checkClipConnection(rfsv &a, rclip & rc, ppsocket & rclipSocket)
+{
+    if (canClip == false)
+        return false;
+
+    if (a.getProtocolVersion() == 3) {
+        cerr << _("Clipboard protocol not supported by Psion Series 3.") << endl;
+        return false;
+    }
+
+    Enum<rfsv::errs> ret;
+    if ((ret = rc.initClipbd()) == rfsv::E_PSI_GEN_NONE)
+        return true;
+    else if (ret == rfsv::E_PSI_GEN_NSUP)
+        cerr << _("Your Psion does not support the clipboard protocol.\n\
+                The reason for that is usually a missing server library.\n\
+                Make sure that C:\\System\\Libs\\clipsvr.rsy exists.\n\
+                This file is part of PsiWin and usually gets copied to\n\
+                your Psion when you enable CopyAnywhere in PsiWin.\n\
+                You can also get it from a PsiWin installation directory\n\
+                and copy it to your Psion manually.") << endl;
+    return false;
+}
+
+static void
+psiText2ascii(char *buf, int len) {
+    char *p;
+
+    for (p = buf; len; len--, p++)
+	switch (*p) {
+	    case 6:
+	    case 7:
+		*p = '\n';
+		break;
+	    case 8:
+		*p = '\f';
+		break;
+	    case 10:
+		*p = '\t';
+		break;
+	    case 11:
+	    case 12:
+		*p = '-';
+		break;
+	    case 15:
+	    case 16:
+		*p = ' ';
+		break;
+	}
+}
+
+static void
+ascii2PsiText(char *buf, int len) {
+    char *p;
+
+    for (p = buf; len; len--, p++)
+	switch (*p) {
+            case '\0':
+                *p = ' ';
+	    case '\n':
+		*p = 6;
+		break;
+	    case '\f':
+		*p = 8;
+		break;
+	    case '-':
+		*p = 11;
+		break;
+	}
+}
+
+static char *
+slurp(FILE *fp, size_t *final_len)
+{
+    return get_upto(fp, "", final_len);
+}
+
+int
+ftp::putClipText(rpcs & r, rfsv & a, rclip & rc, ppsocket & rclipSocket, const char *file)
+{
+    Enum<rfsv::errs> res;
+    u_int32_t fh;
+    u_int32_t l;
+    const unsigned char *p;
+    bufferStore b;
+    char *data;
+    FILE *fp;
+
+    if (!checkClipConnection(a, rc, rclipSocket))
+        return 1;
+
+    if ((fp = fopen(file, "r")) == NULL)
+        return 1;
+
+    size_t len;
+    data = slurp(fp, &len);
+    fclose(fp);
+    ascii2PsiText(data, len);
+        
+    res = a.freplacefile(0x200, CLIPFILE, fh);
+    if (res == rfsv::E_PSI_GEN_NONE) {
+	// Base Header
+	b.addDWord(0x10000037);   // @00 UID 0
+	b.addDWord(0x1000003b);   // @04 UID 1
+	b.addDWord(0);            // @08 UID 3
+	b.addDWord(0x4739d53b);   // @0c Checksum the above
+
+	// Section Table
+	b.addDWord(0x00000014);   // @10 Offset of Section Table
+	b.addByte(2);             // @14 Section Table, length in DWords
+	b.addDWord(0x10000033);   // @15 Section Type (ASCII)
+	b.addDWord(0x0000001d);   // @19 Section Offset
+
+	// Data
+	b.addDWord(strlen(data)); // @1e Section (String) length
+	b.addStringT(data);       // @22 Data (Psion Word seems to need a
+                                  //     terminating 0.
+
+	p = (const unsigned char *)b.getString(0);
+	a.fwrite(fh, p, b.getLen(), l);
+	a.fclose(fh);
+	a.fsetattr(CLIPFILE, 0x20, 0x07);
+    }
+
+    return 0;
+}
+
+// FIXME: Make this work as putclipimg
+
+// static QImage *putImage;
+
+// static int
+// getGrayPixel(int x, int y)
+// {
+//     return qGray(putImage->pixel(x, y));
+// }
+
+// void TopLevel::
+// putClipImage(QImage &img) {
+//     Enum<rfsv::errs> res;
+//     u_int32_t fh;
+//     u_int32_t l;
+//     const unsigned char *p;
+//     bufferStore b;
+
+//     res = rf->freplacefile(0x200, CLIPFILE, fh);
+//     if (res == rfsv::E_PSI_GEN_NONE) {
+// 	while ((res = rc->checkNotify()) != rfsv::E_PSI_GEN_NONE) {
+// 	    if (res != rfsv::E_PSI_FILE_EOF) {
+// 		rf->fclose(fh);
+// 		closeConnection();
+// 		return;
+// 	    }
+// 	}
+
+// 	// Base Header
+// 	b.addDWord(0x10000037);   // @00 UID 0
+// 	b.addDWord(0x1000003b);   // @04 UID 1
+// 	b.addDWord(0);            // @08 UID 3
+// 	b.addDWord(0x4739d53b);   // @0c Checksum the above
+
+// 	// Section Table
+// 	b.addDWord(0x00000014);   // @10 Offset of Section Table
+// 	b.addByte(2);             // @14 Section Table, length in DWords
+// 	b.addDWord(0x1000003d);   // @15 Section Type (Image)
+// 	b.addDWord(0x0000001d);   // @19 Section Offset
+
+// 	// Data
+// 	bufferStore ib;
+// 	putImage = &img;
+// 	encodeBitmap(img.width(), img.height(), getGrayPixel, false, ib);
+// 	b.addBuff(ib);
+
+// 	p = (const unsigned char *)b.getString(0);
+// 	rf->fwrite(fh, p, b.getLen(), l);
+// 	rf->fclose(fh);
+// 	rf->fsetattr(CLIPFILE, 0x20, 0x07);
+//     } else
+// 	closeConnection();
+// }
+
+// QImage *TopLevel::
+// decode_image(const unsigned char *p)
+// {
+//     bufferStore out;
+//     bufferStore hout;
+//     QImage *img = 0L;
+//     int xPixels;
+//     int yPixels;
+
+//     if (!decodeBitmap(p, xPixels, yPixels, out))
+// 	return img;
+
+//     QString hdr = QString("P5\n%1 %2\n255\n").arg(xPixels).arg(yPixels);
+//     hout.addString(hdr.latin1());
+//     hout.addBuff(out);
+
+//     img = new QImage(xPixels, yPixels, 8);
+//     if (!img->loadFromData((const uchar *)hout.getString(0), hout.getLen())) {
+// 	delete img;
+// 	img = 0L;
+//     }
+//     return img;
+// }
+
+int
+ftp::getClipData(rpcs & r, rfsv & a, rclip & rc, ppsocket & rclipSocket, const char *file) {
+    Enum<rfsv::errs> res;
+    PlpDirent de;
+    u_int32_t fh;
+    string clipText;
+
+    res = a.fgeteattr(CLIPFILE, de);
+    if (res == rfsv::E_PSI_GEN_NONE) {
+	if (de.getAttr() & rfsv::PSI_A_ARCHIVE) {
+	    u_int32_t len = de.getSize();
+	    char *buf = (char *)malloc(len);
+
+	    if (!buf) {
+		cerr << "Out of memory in getClipData" << endl;
+		return 1;
+	    }
+	    res = a.fopen(a.opMode(rfsv::PSI_O_RDONLY | rfsv::PSI_O_SHARE),
+			   CLIPFILE, fh);
+	    if (res == rfsv::E_PSI_GEN_NONE) {
+		u_int32_t tmp;
+		res = a.fread(fh, (unsigned char *)buf, len, tmp);
+		a.fclose(fh);
+
+		if ((res == rfsv::E_PSI_GEN_NONE) && (tmp == len)) {
+		    char *p = buf;
+		    int lcount;
+		    u_int32_t     *ti = (u_int32_t*)buf;
+
+		    // Check base header
+		    if (*ti++ != 0x10000037) {
+			free(buf);
+			return 1;
+		    }
+		    if (*ti++ != 0x1000003b) {
+			free(buf);
+			return 1;
+		    }
+		    if (*ti++ != 0) {
+			free(buf);
+			return 1;
+		    }
+		    if (*ti++ != 0x4739d53b) {
+			free(buf);
+			return 1;
+		    }
+
+		    // Start of section table
+		    p = buf + *ti;
+		    // Length of section table (in DWords)
+		    lcount = *p++;
+
+		    u_int32_t *td = (u_int32_t*)p;
+		    while (lcount > 0) {
+			u_int32_t sType = *td++;
+			if (sType == 0x10000033) {
+			    // An ASCII section
+			    p = buf + *td;
+			    len = *((u_int32_t*)p);
+			    p += 4;
+			    psiText2ascii(p, len);
+			    clipText += (char *)p;
+			}
+			if (sType == 0x1000003d) {
+// FIXME: Implement this
+// 			    // A paint data section
+// 			    p = buf + *td;
+// 			    if (clipImg)
+// 				delete clipImg;
+// 			    clipImg = decode_image((const unsigned char *)p);
+			}
+			td++;
+			lcount -= 2;
+		    }
+		}
+
+	    }
+	    free(buf);
+	}
+    }
+
+    FILE *fp = fopen(file, "w");
+    if (fp == NULL)
+        return 1;
+    fwrite(clipText.c_str(), 1, clipText.length(), fp);
+    return 0;
+}
+
 int ftp::
-session(rfsv & a, rpcs & r, int xargc, char **xargv)
+session(rfsv & a, rpcs & r, rclip & rc, ppsocket & rclipSocket, int xargc, char **xargv)
 {
     int argc;
     char *argv[10];
@@ -760,7 +1199,7 @@ session(rfsv & a, rpcs & r, int xargc, char **xargv)
 	    if (strlen(cmd))
 		system(cmd);
 	    else {
-		char *sh;
+		const char *sh;
 		cout << _("Starting subshell ...\n");
 		sh = getenv("SHELL");
 		if (!sh)
@@ -770,18 +1209,6 @@ session(rfsv & a, rpcs & r, int xargc, char **xargv)
 	    continue;
 	}
 	// RPCS commands
-#ifdef EXPERIMENTAL
-	if (!strcmp(argv[0], "x")) {
-	    u_int16_t hhh;
-	    if (r.regOpenIter((u_int32_t)-1, "%PDF-", hhh)
-		== rfsv::E_PSI_GEN_NONE) {
-		Enum<rfsv::errs> res;
-		while ((res = r.regReadIter(hhh)) == rfsv::E_PSI_GEN_NONE)
-			;;
-	    }
-	    continue;
-	}
-#endif
 	if (!strcmp(argv[0], "settime")) {
 	    if ((res = r.setTime(time(NULL))) != rfsv::E_PSI_GEN_NONE)
 		cerr << _("Error: ") << res << endl;
@@ -936,87 +1363,23 @@ session(rfsv & a, rpcs & r, int xargc, char **xargv)
 	    continue;
 	}
 	if (!strcmp(argv[0], "runrestore") && (argc == 2)) {
-	    ifstream ip(argv[1]);
-	    char cmd[512];
-	    char arg[512];
-
-	    if (!ip) {
-		cerr << _("Could not read processlist ") << argv[1] << endl;
-		continue;
-	    }
-	    ip >> cmd >> arg;
-
-	    if (strcmp(cmd, "#plpftp") || strcmp(arg, "processlist")) {
-		ip.close();
-		cerr << _("Error: ") << argv[1] <<
-		    _(" is not a process list saved with killsave") << endl;
-		continue;
-	    }
-	    while (!ip.eof()) {
-		ip >> cmd >> arg;
-		ip.get(&arg[strlen(arg)], sizeof(arg) - strlen(arg), '\n');
-		// cout << "cmd=\"" << cmd << "\" arg=\"" << arg << "\"" << endl;
-		if (strlen(cmd) > 0) {
-		    // Workaround for broken programs like Backlite. These do not store
-		    // the full program path. In that case we try running the arg1 which
-		    // results in starting the program via recog. facility.
-		    if ((strlen(arg) > 2) && (arg[1] == ':') && (arg[0] >= 'A') &&
-			(arg[0] <= 'Z'))
-			res = r.execProgram(arg, "");
-		    else
-			res = r.execProgram(cmd, arg);
-		    if (res != rfsv::E_PSI_GEN_NONE) {
-			// If we got an error here, that happened probably because
-			// we have no path at all (e.g. Macro5) and the program is not
-			// registered in the Psion's path properly. Now try the ususal
-			// \System\Apps\<AppName>\<AppName>.app on all drives.
-			if (strchr(cmd, '\\') == NULL) {
-			    u_int32_t devbits;
-			    char tmp[512];
-			    if ((res = a.devlist(devbits)) == rfsv::E_PSI_GEN_NONE) {
-				int i;
-				for (i = 0; i < 26; i++) {
-				    if (devbits & 1) {
-					sprintf(tmp,
-						"%c:\\System\\Apps\\%s\\%s.app",
-						'A' + i, cmd, cmd);
-					res = r.execProgram(tmp, "");
-				    }
-				    if (res == rfsv::E_PSI_GEN_NONE)
-					break;
-				}
-			    }
-			}
-		    }
-		    if (res != rfsv::E_PSI_GEN_NONE) {
-			cerr << _("Could not start ") << cmd << " " << arg << endl;
-			cerr << _("Error: ") << res << endl;
-		    }
-		}
-	    }
-	    ip.close();
-	    continue;
+            startPrograms(r, a, argv[1]);
+            continue;
 	}
 	if (!strcmp(argv[0], "killsave") && (argc == 2)) {
-	    processList tmp;
-	    if ((res = r.queryPrograms(tmp)) != rfsv::E_PSI_GEN_NONE)
-		cerr << _("Error: ") << res << endl;
-	    else {
-		ofstream op(argv[1]);
-		if (!op) {
-		    cerr << _("Could not write processlist ") << argv[1] << endl;
-		    continue;
-		}
-		op << "#plpftp processlist" << endl;
-		processList::iterator i;
-		for (i = tmp.begin(); i != tmp.end(); i++) {
-		    op << i->getArgs() << endl;
-		    r.stopProgram(i->getProcId());
-		}
-		op.close();
-	    }
+	    stopPrograms(r, argv[1]);
 	    continue;
 	}
+        if (!strcmp(argv[0], "putclip") && (argc == 2)) {
+            if (putClipText(r, a, rc, rclipSocket, argv[1]))
+                cerr << _("Error setting clipboard") << endl;
+            continue;
+        }
+        if (!strcmp(argv[0], "getclip") && (argc == 2)) {
+            if (getClipData(r, a, rc, rclipSocket, argv[1]))
+                cerr << _("Error getting clipboard") << endl;
+            continue;
+        }
 	if (!strcmp(argv[0], "kill") && (argc >= 2)) {
 	    processList tmp;
 	    bool anykilled = false;
@@ -1063,17 +1426,11 @@ session(rfsv & a, rpcs & r, int xargc, char **xargv)
 }
 
 #if HAVE_LIBREADLINE
-#if (READLINE_VERSION >= 402)
 #define FUNCAST(f) f
 #define CPFUNCAST(f) f
 #define MATCHFUNCTION rl_completion_matches
-#else
-#define FUNCAST(f) (Function *)f
-#define CPFUNCAST(f) (CPPFunction *)f
-#define MATCHFUNCTION completion_matches
-#endif
 
-static char *all_commands[] = {
+static const char *all_commands[] = {
     "pwd", "ren", "touch", "gtime", "test", "gattr", "sattr", "devs",
     "dir", "ls", "dircnt", "cd", "lcd", "get", "put", "mget", "mput",
     "del", "rm", "mkdir", "rmdir", "prompt", "bye", "cp", "volname",
@@ -1081,11 +1438,11 @@ static char *all_commands[] = {
     "ownerinfo", "help", "settime", "setupinfo", NULL
 };
 
-static char *localfile_commands[] = {
+static const char *localfile_commands[] = {
     "lcd ", "put ", "mput ", "killsave ", "runrestore ", NULL
 };
 
-static char *remote_dir_commands[] = {
+static const char *remote_dir_commands[] = {
     "cd ", "rmdir ", NULL
 };
 
@@ -1095,11 +1452,7 @@ static char cplPath[1024];
 
 static char*
 filename_generator(
-#if (READLINE_VERSION >= 402)
 				   const char *text,
-#else
-				   char *text,
-#endif
 				   int state)
 {
     static int len;
@@ -1138,15 +1491,11 @@ filename_generator(
 
 static char *
 command_generator(
-#if (READLINE_VERSION >= 402)
 		  const char *text,
-#else
-		  char *text,
-#endif
 		  int state)
 {
     static int idx, len;
-    char *name;
+    const char *name;
 
     if (!state) {
 	idx = 0;
@@ -1160,15 +1509,9 @@ command_generator(
     return NULL;
 }
 
-#if (READLINE_VERSION >= 402)
 static char * null_completion(const char *, int) {
     return "";
 }
-#else
-static int null_completion() {
-    return 0;
-}
-#endif
 
 static char **
 do_completion(const char *text, int start, int end)
@@ -1177,23 +1520,16 @@ do_completion(const char *text, int start, int end)
 
     rl_completion_entry_function = FUNCAST(null_completion);
     rl_completion_append_character = ' ';
-#if (READLINE_VERSION >= 402)
     rl_attempted_completion_over = 1;
-#endif
     if (start == 0)
 	{
 #if HAVE_LIBREADLINE
-# if (READLINE_VERSION >= 402)
 	matches = MATCHFUNCTION(text, command_generator);
-# else
-	char* txt = (char*)text;
-	matches = MATCHFUNCTION(txt, (CPFunction*)command_generator);
-# endif
 #endif
 	}
     else {
 	int idx = 0;
-	char *name;
+	const char *name;
 	char *p;
 
 	rl_filename_quoting_desired = 1;
@@ -1219,14 +1555,7 @@ do_completion(const char *text, int start, int end)
 	}
 
 #if HAVE_LIBREADLINE
-# if (READLINE_VERSION >= 402)
 	matches = MATCHFUNCTION(text, filename_generator);
-# else
-	{
-	char* txt = (char*)text;
-	matches = MATCHFUNCTION(txt, (CPFunction*)filename_generator);
-	}
-# endif
 #endif
     }
     return matches;
@@ -1240,13 +1569,8 @@ initReadline(void)
     rl_readline_name = "plpftp";
     rl_completion_entry_function = FUNCAST(null_completion);
     rl_attempted_completion_function = CPFUNCAST(do_completion);
-#if (READLINE_VERSION < 402)
-    rlcrap_setpointers(command_generator, filename_generator);
-#endif
-#if (READLINE_VERSION >= 402)
     rl_basic_word_break_characters = " \t\n\"\\'`@><=;|&{(";
 #endif
-#endif
 }
 
 void ftp::
