@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: ftp.h,v 1.6 2002/02/28 20:59:11 felfert Exp $
+ * $Id: ftp.h,v 1.8 2007/11/20 21:31:29 rrt Exp $
  *
  * This file is part of plptools.
  *
@@ -38,11 +38,15 @@ class ftp {
 	public:
 	ftp();
 	~ftp();
-	int session(rfsv & a, rpcs & r, int xargc, char **xargv);
+        int session(rfsv & a, rpcs & r, rclip & rc, ppsocket & rclipSocket, int xargc, char **xargv);
+        bool canClip;
 
-	 private:
+	private:
 	void getCommand(int &argc, char **argv);
 	void initReadline(void);
+        int putClipText(rpcs & r, rfsv & a, rclip & rc, ppsocket & rclipSocket, const char *data);
+        int getClipData(rpcs & r, rfsv & a, rclip & rc, ppsocket & rclipSocket, const char *file);
+        bool checkClipConnection(rfsv &a, rclip & rc, ppsocket & rclipSocket);
 
 	// utilities
 	bool unixDirExists(const char *dir);
@@ -60,7 +64,6 @@ class ftp {
 #endif
 	char defDrive[9];
 	char localDir[1024];
-	// char psionDir[1024];
 };
 
 #endif
